from setuptools import setup

setup(
    name='NlpToolkit-PropBank',
    version='1.0.12',
    packages=['PropBank'],
    url='https://github.com/olcaytaner/TurkishPropbank-Py',
    license='',
    author='olcaytaner',
    author_email='olcaytaner@isikun.edu.tr',
    description='Turkish PropBank'
)
